@@ -135,7 +135,7 @@ static NSArray	*colors = nil;
 
     /* calc lat/lon from point */
     pt = [map latLonForPointOnMap:p];
-printf("%s  p = {%f %f} -> lon = %f, lat = %f\n", [[date description] cString], p.x, p.y, pt.x, pt.y);
+printf("%s  p = {%f %f} -> lon = %f, lat = %f\n", [[date description] UTF8String], p.x, p.y, pt.x, pt.y);
 
     dict = [NSMutableDictionary dictionary];
     [dict setObject:@"Map Chart" forKey:@"name"];
