@@ -1301,7 +1301,7 @@ NSLog(@"createMap: scale = %f", scale);
             for (l=0; l<[layerList count]; l++)
             {
                 if ( [[[layerList objectAtIndex:l] string] rangeOfString:idStr].length &&
-                     [[layerList objectAtIndex:l] state] )
+                     [(LayerObject*)[layerList objectAtIndex:l] state] )
                 {   NSString	*formatStr;
 
                     layer = [layerList objectAtIndex:l];
@@ -1350,7 +1350,7 @@ NSLog(@"createMap: scale = %f", scale);
     /* if background layer is off
      * we copy gray pixels from background over white pixels of map
      */
-    if (![[[view layerList] objectAtIndex:layerBG] state])
+    if (![(LayerObject*)[[view layerList] objectAtIndex:layerBG] state])
     {   NSBitmapImageRep	*repMap = [reps objectAtIndex:0], *repBG;
         unsigned char		*planesMap[5], *planesBG[5];
         NSArray			*list = [[[view layerList] objectAtIndex:layerBG] list];
